# Previewing Templates and Creating Diagrams from Templates
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/previewing-templates-and-creating-diagrams-from-templates#overview)
  * [Limitations](https://help.sap.com/docs/leanix/ea/previewing-templates-and-creating-diagrams-from-templates#limitations)
  * [Previewing Diagram Templates](https://help.sap.com/docs/leanix/ea/previewing-templates-and-creating-diagrams-from-templates#previewing-diagram-templates)
  * [Sharing Template Previews by URL](https://help.sap.com/docs/leanix/ea/previewing-templates-and-creating-diagrams-from-templates#sharing-template-previews-by-url)
  * [Creating a Free Draw Diagram from a Template Preview](https://help.sap.com/docs/leanix/ea/previewing-templates-and-creating-diagrams-from-templates#creating-a-free-draw-diagram-from-a-template-preview)


Template previews provide dynamic, real-time diagrams of your current inventory. Use this feature to visualize data, collaborate with stakeholders, and generate static diagrams as needed.
